==> antragsgruen-3.6.8.tar.bz2: antragsgruen-3.6.8/messages/de/structure.php <==
<?php
return [
    'section_title'   => 'Titel',
    'section_text'    => 'Text',
    'section_html'    => 'Text (erweitert)',
    'section_image'   => 'Bild',
    'section_tabular' => 'Tabellarische Angaben',
    'section_pdf'     => 'PDF-Datei',

    'policy_deadline_over'    => 'Der Antragsschluss ist vorbei',
    'policy_ww_title'         => 'Wurzelwerk-Nutzer*innen',
    'policy_ww_desc'          => 'Wurzelwerk-Nutzer*innen',
    'policy_ww_motion_denied' => 'Nur Wurzelwerk-Nutzer*innen dürfen Anträge anlegen.',
    'policy_ww_amend_denied'  => 'Nur Wurzelwerk-Nutzer*innen dürfen Änderungsanträge anlegen.',
    'policy_ww_comm_denied'   => 'Nur Wurzelwerk-Nutzer*innen dürfen kommentieren',
    'policy_ww_supp_denied'   => 'Nur Wurzelwerk-Nutzer*innen dürfen unterstützen',

    'policy_admin_title'         => 'Admins',
    'policy_admin_desc'          => 'Admins',
    'policy_admin_motion_denied' => 'Nur Admins dürfen Anträge anlegen.',
    'policy_admin_amend_denied'  => 'Nur Admins dürfen Änderungsanträge anlegen.',
    'policy_admin_comm_denied'   => 'Nur Admins dürfen kommentieren',
    'policy_admin_supp_denied'   => 'Nur Admins dürfen unterstützen',

    'policy_all_title'            => 'Alle',
    'policy_all_desc'             => 'Alle',
    'policy_nobody_title'         => 'Niemand',
    'policy_nobody_motion_denied' => 'Momentan kann niemand Anträge stellen.',
    'policy_nobody_amend_denied'  => 'Momentan kann niemand Änderungsanträge stellen.',
    'policy_nobody_comm_denied'   => 'Momentan kann niemand Kommentare schreiben.',
    'policy_nobody_supp_denied'   => 'Momentan kann niemand unterstützen.',

    'policy_logged_title'           => 'Eingeloggte',
    'policy_logged_desc'            => 'Eingeloggte',
    'policy_specuser_motion_denied' => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Anträge stellen.',
    'policy_specuser_amend_denied'  => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Änderungsanträge stellen.',
    'policy_specuser_supp_denied'   => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Anträge unterstützen.',
    'policy_specuser_comm_denied'   => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Kommentare schreiben.',
    'policy_logged_motion_denied'   => 'Du musst dich einloggen, um Anträge stellen zu können.',
    'policy_logged_amend_denied'    => 'Du musst dich einloggen, um Änderungsanträge stellen zu können.',
    'policy_logged_supp_denied'     => 'Du musst dich einloggen, um Anträge unterstützen zu können.',
    'policy_logged_comm_denied'     => 'Du musst dich einloggen, um Kommentare schreiben zu können.',

    'preset_bdk_name'           => 'BDK-ähnlich',
    'preset_bdk_desc'           => 'Benutzer*innen mit Wurzelwerk-Zugang können Anträge und Änderungsanträge stellen, die zunächst von der Antragskommission auf Zulässigkeit geprüft werden. Neben der Antragsteller*in müssen 19 Unterstützer*innen angegegeb werden. Das Grüne CI ist standardmäßig voreingestellt.',
    'preset_election_name'      => 'Bewerbungsverfahren',
    'preset_election_desc'      => 'irgendwas zum Bewerbungsverfahren',
    'preset_motions_name'       => 'Anträge',
    'preset_motions_desc'       => 'Benutzer*innen können Anträge und Änderungsanträge stellen, die zunächst von der Antragskommission auf Zulässigkeit geprüft werden. Kein Login zur Nutzung nötig.',
    'preset_party_name'         => 'Parteitag',
    'preset_party_desc'         => 'Ein Parteitag mit beispielshaft voreingestellter Tagesordnung wird angelegt. Benutzer*innen können Anträge und Änderungsanträge stellen und Bewerbungsformulare für Ämter ausfüllen. Die Tagesordnung, zur Wahl stehenden Ämter können beliebig angepasst werden.',
    'preset_party_top'          => 'Tagesordnung',
    'preset_party_elections'    => 'Wahlen',
    'preset_party_1leader'      => 'Wahl: 1. Vorsitzende(r)',
    'preset_party_2leader'      => 'Wahl: 2. Vorsitzende(r)',
    'preset_party_treasure'     => 'Wahl: Schatzmeister(in)',
    'preset_party_motions'      => 'Anträge',
    'preset_party_misc'         => 'Sonstiges',
    'preset_manifesto_name'     => 'Wahlprogramm',
    'preset_manifesto_desc'     => 'Ein Entwurf eines Wahlprogramms wird von der Programmkommission online gestellt. Benutzer*innen können Kommentare und Änderungsanträge stellen. Letztere müssen von der Programmkommission zunächst freigeschaltet werden. Kein Login zur Nutzung nötig.',
    'preset_manifesto_title'    => 'Kapiteltitel',
    'preset_manifesto_text'     => 'Text',
    'preset_manifesto_singular' => 'Kapitel',
    'preset_manifesto_plural'   => 'Kapitel',
    'preset_manifesto_call'     => 'Kapitel anlegen',

    'preset_app_singular'  => 'Bewerbung',
    'preset_app_plural'    => 'Bewerbungen',
    'preset_app_call'      => 'Bewerben',
    'preset_app_name'      => 'Name',
    'preset_app_photo'     => 'Foto',
    'preset_app_data'      => 'Angaben',
    'preset_app_signature' => 'Unterschrift (eingescannt)',
    'preset_app_age'       => 'Alter',
    'preset_app_gender'    => 'Geschlecht',
    'preset_app_birthcity' => 'Geburtsort',
    'preset_app_intro'     => 'Selbstvorstellung',

    'preset_motion_singular' => 'Antrag',
    'preset_motion_plural'   => 'Anträge',
    'preset_motion_call'     => 'Antrag stellen',
    'preset_motion_title'    => 'Titel',
    'preset_motion_text'     => 'Antragstext',
    'preset_motion_reason'   => 'Begründung',

    'role_initiator' => 'Initiator*in',
    'role_supporter' => 'Unterstützer*in',
    'role_likes'     => 'Mag',
    'role_dislikes'  => 'Mag nicht',

    'person_type_natural' => 'Natürliche Person',
    'person_type_orga'    => 'Organisation / Gremium',

    'user_status_1'  => 'Nicht bestätigt',
    'user_status_0'  => 'Bestätigt',
    'user_status_-1' => 'Gelöscht',

    'STATUS_DELETED'                      => 'Gelöscht',
    'STATUS_WITHDRAWN'                    => 'Zurückgezogen',
    'STATUS_WITHDRAWN_INVISIBLE'          => 'Zurückgezogen (unsichtbar)',
    'STATUS_UNCONFIRMED'                  => 'Unbestätigt',
    'STATUS_DRAFT'                        => 'Entwurf',
    'STATUS_SUBMITTED_UNSCREENED'         => 'Eingereicht (ungeprüft)',
    'STATUS_SUBMITTED_SCREENED'           => 'Eingereicht',
    'STATUS_ACCEPTED'                     => 'Angenommen',
    'STATUS_REJECTED'                     => 'Abgelehnt',
    'STATUS_MODIFIED_ACCEPTED'            => 'Modifiziert übernommen',
    'STATUS_MODIFIED'                     => 'Modifziert',
    'STATUS_ADOPTED'                      => 'Übernahme',
    'STATUS_COMPLETED'                    => 'Erledigt',
    'STATUS_REFERRED'                     => 'Überweisung',
    'STATUS_VOTE'                         => 'Abstimmung',
    'STATUS_PAUSED'                       => 'Pausiert',
    'STATUS_MISSING_INFORMATION'          => 'Informationen fehlen',
    'STATUS_DISMISSED'                    => 'Nicht zugelassen',
    'STATUS_COLLECTING_SUPPORTERS'        => 'Unterstützer*innen sammeln',
    'STATUS_DRAFT_ADMIN'                  => 'Entwurf (Admin)',
    'STATUS_PROCESSED'                    => 'Behandelt',
    'STATUS_SUBMITTED_UNSCREENED_CHECKED' => 'Eingereicht (geprüft, unveröffentlicht)',

    'section_comment_none'      => 'Keine Kommentare',
    'section_comment_motion'    => 'Abschnitt als ganzes kommentierbar',
    'section_comment_paragraph' => 'Einzelne Absätze sind kommentierbar',

    'home_layout_std'         => 'Standard',
    'home_layout_tags'        => 'Tabellarisch, gegliedert nach Schlagworten',
    'home_layout_agenda'      => 'Tagesordnung',
    'home_layout_agenda_long' => 'Tagesordnung (viele Anträge)',

    'supp_only_initiators'    => 'Nur die Antragsteller*in',
    'supp_given_by_initiator' => 'Von der Antragsteller*in angegeben',
    'supp_collect_before'     => 'Unterstützungs-Phase vor Veröffentlichung (außer bei Gremien)',

    'activity_none'                       => 'Noch keine Aktivitäten',
    'activity_someone'                    => 'Ein*e Benutzer*in',
    'activity_deleted'                    => 'gelöscht',
    'activity_MOTION_DELETE'              => '###USER### hat einen <strong>Antrag ###MOTION### gelöscht</strong>',
    'activity_MOTION_DELETE_PUBLISHED'    => '###USER### hat den <strong>Antrag ###MOTION### nachträglich gelöscht</strong>',
    'activity_MOTION_PUBLISH'             => '###USER### hat den <strong>Antrag eingereicht</strong>',
    'activity_MOTION_WITHDRAW'            => 'Der Antrag wurde <strong>zurückgezogen</strong>.',
    'activity_MOTION_COMMENT'             => '###USER### hat den <strong>Antrag kommentiert</strong>',
    'activity_MOTION_SCREEN'              => 'Der <strong>Antrag</strong> wurde <strong>veröffentlicht</strong>',
    'activity_AMENDMENT_PUBLISH'          => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### eingereicht</strong>',
    'activity_AMENDMENT_CHANGE'           => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### überarbeitet</strong>',
    'activity_AMENDMENT_DELETE'           => '###USER### hat einen <strong>Änderungsantrag ###AMENDMENT### gelöscht</strong>',
    'activity_AMENDMENT_DELETE_PUBLISHED' => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### nachträglich gelöscht</strong>',
    'activity_AMENDMENT_WITHDRAW'         => 'Der <strong> Änderungsantrag ###AMENDMENT###</strong> wurde <strong>zurückgezogen</strong>.',
    'activity_AMENDMENT_COMMENT'          => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### kommentiert</strong>',
    'activity_AMENDMENT_SCREEN'           => 'Der <strong>Änderungsantrag ###AMENDMENT###</strong> wurde <strong>veröffentlicht</strong>',
];

==> antragsgruen-3.7.1.tar.bz2: antragsgruen-3.7.1/messages/de/structure.php <==
<?php
return [
    'section_title'   => 'Titel',
    'section_text'    => 'Text',
    'section_html'    => 'Text (erweitert)',
    'section_image'   => 'Bild',
    'section_tabular' => 'Tabellarische Angaben',
    'section_pdf'     => 'PDF-Datei',

    'amend_number_permotion' => 'Ä1 zu A1 (Zählung pro Antrag)',
    'amend_number_global'    => 'Ä1 zu A1 (Globale Zählung)',
    'amend_number_perline'   => 'A01-070 (Zählung nach betroffener Zeile)',

    'policy_deadline_over'    => 'Der Antragsschluss ist vorbei',
    'policy_ww_title'         => 'Wurzelwerk-Nutzer*innen',
    'policy_ww_desc'          => 'Wurzelwerk-Nutzer*innen',
    'policy_ww_motion_denied' => 'Nur Wurzelwerk-Nutzer*innen dürfen Anträge anlegen.',
    'policy_ww_amend_denied'  => 'Nur Wurzelwerk-Nutzer*innen dürfen Änderungsanträge anlegen.',
    'policy_ww_comm_denied'   => 'Nur Wurzelwerk-Nutzer*innen dürfen kommentieren',
    'policy_ww_supp_denied'   => 'Nur Wurzelwerk-Nutzer*innen dürfen unterstützen',

    'policy_admin_title'         => 'Admins',
    'policy_admin_desc'          => 'Admins',
    'policy_admin_motion_denied' => 'Nur Admins dürfen Anträge anlegen.',
    'policy_admin_amend_denied'  => 'Nur Admins dürfen Änderungsanträge anlegen.',
    'policy_admin_comm_denied'   => 'Nur Admins dürfen kommentieren',
    'policy_admin_supp_denied'   => 'Nur Admins dürfen unterstützen',

    'policy_all_title'            => 'Alle',
    'policy_all_desc'             => 'Alle',
    'policy_nobody_title'         => 'Niemand',
    'policy_nobody_motion_denied' => 'Momentan kann niemand Anträge stellen.',
    'policy_nobody_amend_denied'  => 'Momentan kann niemand Änderungsanträge stellen.',
    'policy_nobody_comm_denied'   => 'Momentan kann niemand Kommentare schreiben.',
    'policy_nobody_supp_denied'   => 'Momentan kann niemand unterstützen.',

    'policy_logged_title'           => 'Eingeloggte',
    'policy_logged_desc'            => 'Eingeloggte',
    'policy_specuser_motion_denied' => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Anträge stellen.',
    'policy_specuser_amend_denied'  => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Änderungsanträge stellen.',
    'policy_specuser_supp_denied'   => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Anträge unterstützen.',
    'policy_specuser_comm_denied'   => 'Nur von den Administrator*innen explizit zugelassene Benutzer*innen können Kommentare schreiben.',
    'policy_logged_motion_denied'   => 'Du musst dich einloggen, um Anträge stellen zu können.',
    'policy_logged_amend_denied'    => 'Du musst dich einloggen, um Änderungsanträge stellen zu können.',
    'policy_logged_supp_denied'     => 'Du musst dich einloggen, um Anträge unterstützen zu können.',
    'policy_logged_comm_denied'     => 'Du musst dich einloggen, um Kommentare schreiben zu können.',

    'preset_bdk_name'           => 'BDK-ähnlich',
    'preset_bdk_desc'           => 'Benutzer*innen mit Wurzelwerk-Zugang können Anträge und Änderungsanträge stellen, die zunächst von der Antragskommission auf Zulässigkeit geprüft werden. Neben der Antragsteller*in müssen 19 Unterstützer*innen angegegeb werden. Das Grüne CI ist standardmäßig voreingestellt.',
    'preset_election_name'      => 'Bewerbungsverfahren',
    'preset_election_desc'      => 'irgendwas zum Bewerbungsverfahren',
    'preset_motions_name'       => 'Anträge',
    'preset_motions_desc'       => 'Benutzer*innen können Anträge und Änderungsanträge stellen, die zunächst von der Antragskommission auf Zulässigkeit geprüft werden. Kein Login zur Nutzung nötig.',
    'preset_party_name'         => 'Parteitag',
    'preset_party_desc'         => 'Ein Parteitag mit beispielshaft voreingestellter Tagesordnung wird angelegt. Benutzer*innen können Anträge und Änderungsanträge stellen und Bewerbungsformulare für Ämter ausfüllen. Die Tagesordnung, zur Wahl stehenden Ämter können beliebig angepasst werden.',
    'preset_party_top'          => 'Tagesordnung',
    'preset_party_elections'    => 'Wahlen',
    'preset_party_1leader'      => 'Wahl: 1. Vorsitzende(r)',
    'preset_party_2leader'      => 'Wahl: 2. Vorsitzende(r)',
    'preset_party_treasure'     => 'Wahl: Schatzmeister(in)',
    'preset_party_motions'      => 'Anträge',
    'preset_party_misc'         => 'Sonstiges',
    'preset_manifesto_name'     => 'Wahlprogramm',
    'preset_manifesto_desc'     => 'Ein Entwurf eines Wahlprogramms wird von der Programmkommission online gestellt. Benutzer*innen können Kommentare und Änderungsanträge stellen. Letztere müssen von der Programmkommission zunächst freigeschaltet werden. Kein Login zur Nutzung nötig.',
    'preset_manifesto_title'    => 'Kapiteltitel',
    'preset_manifesto_text'     => 'Text',
    'preset_manifesto_singular' => 'Kapitel',
    'preset_manifesto_plural'   => 'Kapitel',
    'preset_manifesto_call'     => 'Kapitel anlegen',

    'preset_app_singular'  => 'Bewerbung',
    'preset_app_plural'    => 'Bewerbungen',
    'preset_app_call'      => 'Bewerben',
    'preset_app_name'      => 'Name',
    'preset_app_photo'     => 'Foto',
    'preset_app_data'      => 'Angaben',
    'preset_app_signature' => 'Unterschrift (eingescannt)',
    'preset_app_age'       => 'Alter',
    'preset_app_gender'    => 'Geschlecht',
    'preset_app_birthcity' => 'Geburtsort',
    'preset_app_intro'     => 'Selbstvorstellung',

    'preset_motion_singular' => 'Antrag',
    'preset_motion_plural'   => 'Anträge',
    'preset_motion_call'     => 'Antrag stellen',
    'preset_motion_title'    => 'Titel',
    'preset_motion_text'     => 'Antragstext',
    'preset_motion_reason'   => 'Begründung',

    'role_initiator' => 'Initiator*in',
    'role_supporter' => 'Unterstützer*in',
    'role_likes'     => 'Mag',
    'role_dislikes'  => 'Mag nicht',

    'person_type_natural' => 'Natürliche Person',
    'person_type_orga'    => 'Organisation / Gremium',

    'user_status_1'  => 'Nicht bestätigt',
    'user_status_0'  => 'Bestätigt',
    'user_status_-1' => 'Gelöscht',

    'STATUS_DELETED'                      => 'Gelöscht',
    'STATUS_WITHDRAWN'                    => 'Zurückgezogen',
    'STATUS_WITHDRAWN_INVISIBLE'          => 'Zurückgezogen (unsichtbar)',
    'STATUS_UNCONFIRMED'                  => 'Unbestätigt',
    'STATUS_DRAFT'                        => 'Entwurf',
    'STATUS_SUBMITTED_UNSCREENED'         => 'Eingereicht (ungeprüft)',
    'STATUS_SUBMITTED_SCREENED'           => 'Eingereicht',
    'STATUS_ACCEPTED'                     => 'Angenommen',
    'STATUS_REJECTED'                     => 'Abgelehnt',
    'STATUS_MODIFIED_ACCEPTED'            => 'Modifiziert übernommen',
    'STATUS_MODIFIED'                     => 'Modifziert',
    'STATUS_ADOPTED'                      => 'Übernahme',
    'STATUS_COMPLETED'                    => 'Erledigt',
    'STATUS_REFERRED'                     => 'Überweisung',
    'STATUS_VOTE'                         => 'Abstimmung',
    'STATUS_PAUSED'                       => 'Pausiert',
    'STATUS_MISSING_INFORMATION'          => 'Informationen fehlen',
    'STATUS_DISMISSED'                    => 'Nicht zugelassen',
    'STATUS_COLLECTING_SUPPORTERS'        => 'Unterstützer*innen sammeln',
    'STATUS_DRAFT_ADMIN'                  => 'Entwurf (Admin)',
    'STATUS_PROCESSED'                    => 'Behandelt',
    'STATUS_SUBMITTED_UNSCREENED_CHECKED' => 'Eingereicht (geprüft, unveröffentlicht)',

    'section_comment_none'      => 'Keine Kommentare',
    'section_comment_motion'    => 'Abschnitt als ganzes kommentierbar',
    'section_comment_paragraph' => 'Einzelne Absätze sind kommentierbar',

    'home_layout_std'         => 'Standard',
    'home_layout_tags'        => 'Themen / Schlagworte',
    'home_layout_agenda'      => 'Tagesordnung',
    'home_layout_agenda_long' => 'Tagesordnung (viele Anträge)',

    'supp_only_initiators'    => 'Nur die Antragsteller*in',
    'supp_given_by_initiator' => 'Von der Antragsteller*in angegeben',
    'supp_collect_before'     => 'Unterstützungs-Phase vor Veröffentlichung (außer bei Gremien)',

    'activity_none'                       => 'Noch keine Aktivitäten',
    'activity_someone'                    => 'Ein*e Benutzer*in',
    'activity_deleted'                    => 'gelöscht',
    'activity_MOTION_DELETE'              => '###USER### hat einen <strong>Antrag ###MOTION### gelöscht</strong>',
    'activity_MOTION_DELETE_PUBLISHED'    => '###USER### hat den <strong>Antrag ###MOTION### nachträglich gelöscht</strong>',
    'activity_MOTION_PUBLISH'             => '###USER### hat den <strong>Antrag eingereicht</strong>',
    'activity_MOTION_WITHDRAW'            => 'Der Antrag wurde <strong>zurückgezogen</strong>.',
    'activity_MOTION_COMMENT'             => '###USER### hat den <strong>Antrag kommentiert</strong>',
    'activity_MOTION_SCREEN'              => 'Der <strong>Antrag</strong> wurde <strong>veröffentlicht</strong>',
    'activity_AMENDMENT_PUBLISH'          => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### eingereicht</strong>',
    'activity_AMENDMENT_CHANGE'           => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### überarbeitet</strong>',
    'activity_AMENDMENT_DELETE'           => '###USER### hat einen <strong>Änderungsantrag ###AMENDMENT### gelöscht</strong>',
    'activity_AMENDMENT_DELETE_PUBLISHED' => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### nachträglich gelöscht</strong>',
    'activity_AMENDMENT_WITHDRAW'         => 'Der <strong> Änderungsantrag ###AMENDMENT###</strong> wurde <strong>zurückgezogen</strong>.',
    'activity_AMENDMENT_COMMENT'          => '###USER### hat den <strong>Änderungsantrag ###AMENDMENT### kommentiert</strong>',
    'activity_AMENDMENT_SCREEN'           => 'Der <strong>Änderungsantrag ###AMENDMENT###</strong> wurde <strong>veröffentlicht</strong>',
];
